# DirectiveViewer
#
# Release 0.01 (Sep 18, 2009)
# Release 0.02 (Sep 25, 2009) for MT4.x
#
# This software is provided as-is. You may use it for commercial or
# personal use. If you distribute it, please keep this notice intact.
#
# Copyright (c) 2004-2009 Yujiro Araki

package MT::Plugin::DirectiveViewer;

use strict;
use warnings;

use MT;
use base qw( MT::Plugin );
use MT::Template;

our $VERSION = '0.02';

my $plugin = __PACKAGE__->new ({
    id   => 'directiveviewer',
    name => 'DirectiveViewer',
    description => '<MT_TRANS phrase="DirectiveViewer.">',
    doc_link => 'http://www.koikikukan.com/archives/2009/09/18-005555.php',
    author_name => 'Yujiro Araki',
    author_link => 'http://www.koikikukan.com/',
    l10n_class => 'DirectiveViewer::L10N',
    version => $VERSION,
});
MT->add_plugin($plugin);

sub init_registry {
    my $plugin = shift;
if(MT->version_number < 5.0){
    $plugin->registry({
        applications => {
            cms => {
                menus => {
                    'tools:show_directive' => {
                        label => "Directive",
                        order => 1000,
                        mode => 'show_directive',
                        view => "system",
                        permission => "administer_blog",
                        system_permission => "administer",
                    },
                },
                methods => {
                    show_directive =>
                        'MT::Plugin::DirectiveViewer::_show_directive',
                },
            },
        },
    });
} else {
    $plugin->registry({
        applications => {
            cms => {
                menus => {
                    'tools:show_directive' => {
                        label => "Directive",
                        order => 1000,
                        mode => 'show_directive',
                        view => ["system"],
                        permission => "administer_blog",
                        system_permission => "administer",
                    },
                },
                methods => {
                    show_directive =>
                        'MT::Plugin::DirectiveViewer::_show_directive',
                },
            },
        },
    });
}
}

sub _show_directive {
    my $app = shift;

    my $cfg = $app->config;
    $app->{plugin_template_path} = File::Spec->catdir($plugin->path,'tmpl');
    my $tmpl = 'show_directive.tmpl';
    my %param;
    $param{'page_title'} = $plugin->translate('Directive');

    $param{'AtomApp_weblog'} = $cfg->AtomApp->{weblog};
    $param{'AtomApp_10'} = $cfg->AtomApp->{1.0};
    $param{'AtomApp_comments'} = $cfg->AtomApp->{comments};

    $param{'CommunityScript'} = $cfg->CommunityScript;
    $param{'EmbedDomainWhitelist'} = $cfg->EmbedDomainWhitelist;

    $param{'SchemaVersion'} = $cfg->SchemaVersion;
    $param{'MTVersion'} = $cfg->MTVersion;
    $param{'NotifyUpgrade'} = $cfg->NotifyUpgrade;
    $param{'Database'} = $cfg->Database;
    $param{'DBHost'} = $cfg->DBHost;
    $param{'DBSocket'} = $cfg->DBSocket;
    $param{'DBPort'} = $cfg->DBPort;
    $param{'DBUser'} = $cfg->DBUser;
    $param{'DBPassword'} = $cfg->DBPassword;
    $param{'DefaultLanguage'} = $cfg->DefaultLanguage;
    $param{'LocalPreviews'} = $cfg->LocalPreviews;
    $param{'DefaultSiteRoot'} = $cfg->DefaultSiteRoot;
    $param{'DefaultSiteURL'} = $cfg->DefaultSiteURL;
    $param{'DefaultCommenterAuth'} = $cfg->DefaultCommenterAuth;
    $param{'TemplatePath'} = $cfg->TemplatePath;
    $param{'WeblogTemplatesPath'} = $cfg->WeblogTemplatesPath;
    $param{'AltTemplatePath'} = $cfg->AltTemplatePath;
    $param{'CSSPath'} = $cfg->CSSPath;
    $param{'ImportPath'} = $cfg->ImportPath;
    $param{'PluginPath'} = $cfg->PluginPath;
    $param{'EnableArchivePaths'} = $cfg->EnableArchivePaths;
    $param{'SearchTemplatePath'} = $cfg->SearchTemplatePath;
    $param{'ObjectDriver'} = $cfg->ObjectDriver;
    $param{'ObjectCacheLimit'} = $cfg->ObjectCacheLimit;
    $param{'ObjectCacheDisabled'} = $cfg->ObjectCacheDisabled;
    $param{'DisableObjectCache'} = $cfg->DisableObjectCache;
    $param{'AllowedTextFilters'} = $cfg->AllowedTextFilters;
    $param{'Serializer'} = $cfg->Serializer;
    $param{'SendMailPath'} = $cfg->SendMailPath;
    $param{'RsyncPath'} = $cfg->RsyncPath;
    $param{'TimeOffset'} = $cfg->TimeOffset;
    $param{'WSSETimeout'} = $cfg->WSSETimeout;
    $param{'StaticWebPath'} = $cfg->StaticWebPath;
    $param{'StaticFilePath'} = $cfg->StaticFilePath;
    $param{'CGIPath'} = $cfg->CGIPath;
    $param{'AdminCGIPath'} = $cfg->AdminCGIPath;
    $param{'CookieDomain'} = $cfg->CookieDomain;
    $param{'CookiePath'} = $cfg->CookiePath;
    $param{'MailEncoding'} = $cfg->MailEncoding;
    $param{'MailTransfer'} = $cfg->MailTransfer;
    $param{'SMTPServer'} = $cfg->SMTPServer;
    $param{'DebugEmailAddress'} = $cfg->DebugEmailAddress;
    $param{'WeblogsPingURL'} = $cfg->WeblogsPingURL;
    $param{'BlogsPingURL'} = $cfg->BlogsPingURL;
    $param{'MTPingURL'} = $cfg->MTPingURL;
    $param{'TechnoratiPingURL'} = $cfg->TechnoratiPingURL;
    $param{'GooglePingURL'} = $cfg->GooglePingURL;
    $param{'CGIMaxUpload'} = $cfg->CGIMaxUpload;
    $param{'DBUmask'} = $cfg->DBUmask;
    $param{'HTMLUmask'} = $cfg->HTMLUmask;
    $param{'UploadUmask'} = $cfg->UploadUmask;
    $param{'DirUmask'} = $cfg->DirUmask;
    $param{'HTMLPerms'} = $cfg->HTMLPerms;
    $param{'UploadPerms'} = $cfg->UploadPerms;
    $param{'NoTempFiles'} = $cfg->NoTempFiles;
    $param{'TempDir'} = $cfg->TempDir;
    $param{'RichTextEditor'} = $cfg->RichTextEditor;
    $param{'EntriesPerRebuild'} = $cfg->EntriesPerRebuild;
    $param{'UseNFSSafeLocking'} = $cfg->UseNFSSafeLocking;
    $param{'NoLocking'} = $cfg->NoLocking;
    $param{'NoHTMLEntities'} = $cfg->NoHTMLEntities;
    $param{'NoCDATA'} = $cfg->NoCDATA;
    $param{'NoPlacementCache'} = $cfg->NoPlacementCache;
    $param{'NoPublishMeansDraft'} = $cfg->NoPublishMeansDraft;
    $param{'IgnoreISOTimezones'} = $cfg->IgnoreISOTimezones;
    $param{'PingTimeout'} = $cfg->PingTimeout;
    $param{'HTTPTimeout'} = $cfg->HTTPTimeout;
    $param{'PingInterface'} = $cfg->PingInterface;
    $param{'HTTPInterface'} = $cfg->HTTPInterface;
    $param{'PingProxy'} = $cfg->PingProxy;
    $param{'HTTPProxy'} = $cfg->HTTPProxy;
    $param{'PingNoProxy'} = $cfg->PingNoProxy;
    $param{'HTTPNoProxy'} = $cfg->HTTPNoProxy;
    $param{'ImageDriver'} = $cfg->ImageDriver;
    $param{'NetPBMPath'} = $cfg->NetPBMPath;
    $param{'AdminScript'} = $cfg->AdminScript;
    $param{'ActivityFeedScript'} = $cfg->ActivityFeedScript;
    $param{'ActivityFeedItemLimit'} = $cfg->ActivityFeedItemLimit;
    $param{'CommentScript'} = $cfg->CommentScript;
    $param{'TrackbackScript'} = $cfg->TrackbackScript;
    $param{'SearchScript'} = $cfg->SearchScript;
    $param{'XMLRPCScript'} = $cfg->XMLRPCScript;
    $param{'ViewScript'} = $cfg->ViewScript;
    $param{'AtomScript'} = $cfg->AtomScript;
    $param{'UpgradeScript'} = $cfg->UpgradeScript;
    $param{'CheckScript'} = $cfg->CheckScript;
    $param{'NotifyScript'} = $cfg->NotifyScript;
    $param{'PublishCharset'} = $cfg->PublishCharset;
    $param{'SafeMode'} = $cfg->SafeMode;
    $param{'GlobalSanitizeSpec'} = $cfg->GlobalSanitizeSpec;
    $param{'GenerateTrackBackRSS'} = $cfg->GenerateTrackBackRSS;
    $param{'NoOverride'} = $cfg->NoOverride;
    $param{'RegexSearch'} = $cfg->RegexSearch;
    $param{'CaseSearch'} = $cfg->CaseSearch;
    $param{'ResultDisplay'} = $cfg->ResultDisplay;
    $param{'ExcerptWords'} = $cfg->ExcerptWords;
    $param{'SearchElement'} = $cfg->SearchElement;
    $param{'ExcludeBlogs'} = $cfg->ExcludeBlogs;
    $param{'IncludeBlogs'} = $cfg->IncludeBlogs;
    $param{'DefaultTemplate'} = $cfg->DefaultTemplate;
    $param{'Type'} = $cfg->Type;
    $param{'MaxResults'} = $cfg->MaxResults;
    $param{'SearchCutoff'} = $cfg->SearchCutoff;
    $param{'CommentSearchCutoff'} = $cfg->CommentSearchCutoff;
    $param{'AltTemplate'} = $cfg->AltTemplate;
    $param{'SearchSortBy'} = $cfg->SearchSortBy;
    $param{'SearchSortOrder'} = $cfg->SearchSortOrder;
    $param{'SearchNoOverride'} = $cfg->SearchNoOverride;
    $param{'SearchResultDisplay'} = $cfg->SearchResultDisplay;
    $param{'SearchExcerptWords'} = $cfg->SearchExcerptWords;
    $param{'SearchDefaultTemplate'} = $cfg->SearchDefaultTemplate;
    $param{'SearchMaxResults'} = $cfg->SearchMaxResults;
    $param{'SearchAltTemplate'} = $cfg->SearchAltTemplate;
    $param{'SearchPrivateTags'} = $cfg->SearchPrivateTags;
    $param{'RegKeyURL'} = $cfg->RegKeyURL;
    $param{'IdentitySystem'} = $cfg->IdentitySystem;
    $param{'SignOnURL'} = $cfg->SignOnURL;
    $param{'SignOffURL'} = $cfg->SignOffURL;
    $param{'IdentityURL'} = $cfg->IdentityURL;
    $param{'DynamicComments'} = $cfg->DynamicComments;
    $param{'SignOnPublicKey'} = $cfg->SignOnPublicKey;
    $param{'ThrottleSeconds'} = $cfg->ThrottleSeconds;
    $param{'SearchCacheTTL'} = $cfg->SearchCacheTTL;
    $param{'SearchThrottleSeconds'} = $cfg->SearchThrottleSeconds;
    $param{'SearchThrottleIPWhitelist'} = $cfg->SearchThrottleIPWhitelist;
    $param{'OneHourMaxPings'} = $cfg->OneHourMaxPings;
    $param{'OneDayMaxPings'} = $cfg->OneDayMaxPings;
    $param{'SupportURL'} = $cfg->SupportURL;
    $param{'NewsURL'} = $cfg->NewsURL;
    $param{'NewsboxURL'} = $cfg->NewsboxURL;
#  $param{'# 'MTNewsURL'} = $cfg-># 'MTNewsURL;
    $param{'LearningNewsURL'} = $cfg->LearningNewsURL;
#  $param{'# 'HackingNewsURL'} = $cfg-># 'HackingNewsURL;
    $param{'EmailAddressMain'} = $cfg->EmailAddressMain;
    $param{'EmailReplyTo'} = $cfg->EmailReplyTo;
    $param{'EmailNotificationBcc'} = $cfg->EmailNotificationBcc;
    $param{'CommentSessionTimeout'} = $cfg->CommentSessionTimeout;
    $param{'UserSessionTimeout'} = $cfg->UserSessionTimeout;
    $param{'UserSessionCookieName'} = $cfg->UserSessionCookieName;
    $param{'UserSessionCookieDomain'} = $cfg->UserSessionCookieDomain;
    $param{'UserSessionCookiePath'} = $cfg->UserSessionCookiePath;
    $param{'UserSessionCookieTimeout'} = $cfg->UserSessionCookieTimeout;
    $param{'LaunchBackgroundTasks'} = $cfg->LaunchBackgroundTasks;
    $param{'TypeKeyVersion'} = $cfg->TypeKeyVersion;
    $param{'TransparentProxyIPs'} = $cfg->TransparentProxyIPs;
    $param{'DebugMode'} = $cfg->DebugMode;
    $param{'ShowIPInformation'} = $cfg->ShowIPInformation;
    $param{'AllowComments'} = $cfg->AllowComments;
    $param{'AllowPings'} = $cfg->AllowPings;
    $param{'HelpURL'} = $cfg->HelpURL;
    $param{'UsePlugins'} = $cfg->UsePlugins;

    # get plugin
    $param{'PluginSwitch'} = $cfg->PluginSwitch;
#    $param{'PluginSchemaVersion'} = $cfg->PluginSchemaVersion->{'core'};

    $param{'OutboundTrackbackLimit'} = $cfg->OutboundTrackbackLimit;
    $param{'OutboundTrackbackDomains'} = $cfg->OutboundTrackbackDomains;
    $param{'IndexBasename'} = $cfg->IndexBasename;
    $param{'LogExportEncoding'} = $cfg->LogExportEncoding;
    $param{'ActivityFeedsRunTasks'} = $cfg->ActivityFeedsRunTasks;
    $param{'ExportEncoding'} = $cfg->ExportEncoding;
    $param{'SQLSetNames'} = $cfg->SQLSetNames;
    $param{'UseSQLite2'} = $cfg->UseSQLite2;
    $param{'UseJcodeModule'} = $cfg->UseJcodeModule;
    $param{'DefaultTimezone'} = $cfg->DefaultTimezone;
    $param{'CategoryNameNodash'} = $cfg->CategoryNameNodash;
    $param{'DefaultListPrefs'} = $cfg->DefaultListPrefs;

    $param{'DefaultEntryPrefs_type'} = $cfg->DefaultEntryPrefs->{type};
    $param{'DefaultEntryPrefs_button'} = $cfg->DefaultEntryPrefs->{button};
    $param{'DefaultEntryPrefs_category'} = $cfg->DefaultEntryPrefs->{category};
    $param{'DefaultEntryPrefs_excerpt'} = $cfg->DefaultEntryPrefs->{excerpt};
    $param{'DefaultEntryPrefs_keywords'} = $cfg->DefaultEntryPrefs->{keywords};
    $param{'DefaultEntryPrefs_tags'} = $cfg->DefaultEntryPrefs->{tags};
#    $param{'DefaultEntryPrefs_height'} = $cfg->DefaultEntryPrefs->{height};

    $param{'DeleteFilesAtRebuild'} = $cfg->DeleteFilesAtRebuild;
    $param{'RebuildAtDelete'} = $cfg->RebuildAtDelete;
    $param{'MaxTagAutoCompletionItems'} = $cfg->MaxTagAutoCompletionItems;
    $param{'NewUserAutoProvisioning'} = $cfg->NewUserAutoProvisioning;
    $param{'NewUserTemplateBlogId'} = $cfg->NewUserTemplateBlogId;
    $param{'DefaultUserLanguage'} = $cfg->DefaultUserLanguage;
    $param{'DefaultUserTagDelimiter'} = $cfg->DefaultUserTagDelimiter;
    $param{'AuthenticationModule'} = $cfg->AuthenticationModule;
    $param{'AuthLoginURL'} = $cfg->AuthLoginURL;
    $param{'AuthLogoutURL'} = $cfg->AuthLogoutURL;
    $param{'DefaultAssignments'} = $cfg->DefaultAssignments;
    $param{'AutoSaveFrequency'} = $cfg->AutoSaveFrequency;
    $param{'FuturePostFrequency'} = $cfg->FuturePostFrequency;
    $param{'AssetCacheDir'} = $cfg->AssetCacheDir;
    $param{'IncludesDir'} = $cfg->IncludesDir;
    $param{'MemcachedServers'} = $cfg->MemcachedServers;
    $param{'MemcachedNamespace'} = $cfg->MemcachedNamespace;
    $param{'MemcachedDriver'} = $cfg->MemcachedDriver;

    $param{'CommenterRegistration_Allow'} = $cfg->CommenterRegistration->{Allow};
    $param{'CommenterRegistration_Notify'} = $cfg->CommenterRegistration->{Notify};

    $param{'CaptchaSourceImageBase'} = $cfg->CaptchaSourceImageBase;
    $param{'SecretToken'} = $cfg->SecretToken;
#   $param{'# NaughtyWordChars settings'} = $cfg->'# NaughtyWordChars settings;
    $param{'NwcSmartReplace'} = $cfg->NwcSmartReplace;
    $param{'NwcReplaceField'} = $cfg->NwcReplaceField;
    $param{'DisableNotificationPings'} = $cfg->DisableNotificationPings;
    $param{'SyncTarget'} = $cfg->SyncTarget;
    $param{'RsyncOptions'} = $cfg->RsyncOptions;
    $param{'UserpicAllowRect'} = $cfg->UserpicAllowRect;
    $param{'UserpicMaxUpload'} = $cfg->UserpicMaxUpload;
    $param{'UserpicThumbnailSize'} = $cfg->UserpicThumbnailSize;
    $param{'AuthorBasenameLimit'} = $cfg->AuthorBasenameLimit;
    $param{'PerformanceLogging'} = $cfg->PerformanceLogging;
    $param{'PerformanceLoggingPath'} = $cfg->PerformanceLoggingPath;
    $param{'PerformanceLoggingThreshold'} = $cfg->PerformanceLoggingThreshold;
    $param{'ProcessMemoryCommand'} = $cfg->ProcessMemoryCommand;
    $param{'EnableAddressBook'} = $cfg->EnableAddressBook;
    $param{'SingleCommunity'} = $cfg->SingleCommunity;
    $param{'DefaultTemplateSet'} = $cfg->DefaultTemplateSet;
    $param{'AssetFileTypes'} = $cfg->AssetFileTypes;
    $param{'FastCGIMaxTime'} = $cfg->FastCGIMaxTime;
    $param{'FastCGIMaxRequests'} = $cfg->FastCGIMaxRequests;

    return $app->build_page($tmpl, \%param);
}


